@@ -264,6 +264,17 @@ def cli_ads_search(args):
     except ValueError as e:
         print(f"\nError: {str(e)}")
 
+    args.bibcode = None
+    args.key = None
+    if args.add:
+        print("\nAdd entry from ADS:")
+        cli_ads_add(args)
+    elif args.fetch or args.open:
+        print("\nFetch/open entry from ADS:")
+        args.keycode = None
+        args.filename = None
+        cli_fetch(args)
+
 
 def cli_ads_add(args):
     """Command-line interface for ads-add call."""
@@ -297,6 +308,12 @@ def cli_ads_add(args):
     except ValueError as e:
         print(f"\nError: {str(e)}")
 
+    if args.fetch or args.open:
+        for bibcode in bibcodes:
+            args.keycode = bibcode
+            args.filename = None
+            cli_fetch(args)
+
 
 def cli_ads_update(args):
     """Command-line interface for ads-update call."""
@@ -332,6 +349,13 @@ def cli_fetch(args):
         filename = prompt_input[1][0]
 
     bib = bm.find(key=key, bibcode=bibcode)
+    if bibcode is not None and bib is None:
+        print("")
+        filename = pm.fetch(bibcode, filename)
+        if args.open and filename is not None:
+            pm.open(pdf_file=filename)
+        return
+
     if bib is None:
         print('\nError: BibTex entry is not in Bibmanager database.')
         return
@@ -815,9 +839,16 @@ Description
   (see 'bibm config ads_display').  If a query matched more entries,
   the user can execute 'bibm ads-search -n' to display the next set of
   entries.
-
   Note that per ADS syntax, fields in quotes must use double quotes.
 
+  If you set the -a/--add flag, the code will prompt to add entries to
+  the database right after showing the ADS search results.
+  Similarly, set the -f/--fetch or -o/--open flags to prompt to fetch
+  or open PDF files right after showing the ADS search results.
+  Note that you can combine these to add and fetch/open at the same
+  time (e.g., bibm ads-search -a -o), or you can fetch/open PDFs that
+  are not in the database (e.g., bibm ads-search -o).
+
 Examples
   # Search entries for author (press tab to prompt the autocompleter):
   bibm ads-search
@@ -860,6 +891,12 @@ Examples
         formatter_class=argparse.RawDescriptionHelpFormatter)
     asearch.add_argument('-n', '--next', action='store_true', default=False,
         help="Display next set of entries that matched the previous query.")
+    asearch.add_argument('-a', '--add', action='store_true', default=False,
+        help="Query to add an entry after displaying the search results.")
+    asearch.add_argument('-f', '--fetch', action='store_true', default=False,
+        help="Query to fetch a PDF after displaying the search results.")
+    asearch.add_argument('-o', '--open', action='store_true', default=False,
+        help="Query to fetch/open a PDF after displaying the search results.")
     asearch.set_defaults(func=cli_ads_search)
 
 
@@ -877,6 +914,10 @@ Description
   By default, added entries replace previously existent entries in the
   bibmanager database.
 
+  With the optional arguments -f/--fetch or -o/--open, the code will
+  attempt to fetch and open (respectively) the associated PDF files
+  of the added entries.
+
 Examples
   # Let's search and add the greatest astronomy PhD thesis of all times:
   bibm ads-search
@@ -891,12 +932,16 @@ Examples
   # Add the entry to the bibmanager database:
   bibm ads-add 1925PhDT.........1P Payne1925phdStellarAtmospheres"""
     ads_add = sp.add_parser('ads-add', description=ads_add_description,
-        usage="bibm ads-add [-h] [bibcode key]",
+        usage="bibm ads-add [-h] [-f] [-o] [bibcode key]",
         formatter_class=argparse.RawDescriptionHelpFormatter)
     ads_add.add_argument('bibcode', action='store', nargs='?',
         help='The ADS bibcode of an entry.')
     ads_add.add_argument('key', action='store', nargs='?',
         help='BibTeX key to assign to the entry.')
+    ads_add.add_argument('-f', '--fetch', action='store_true', default=False,
+        help="Fetch the PDF of the added entries.")
+    ads_add.add_argument('-o', '--open', action='store_true', default=False,
+        help="Fetch and open the PDF of the added entries.")
     ads_add.set_defaults(func=cli_ads_add)
 
 
@@ -947,6 +992,8 @@ Description
   by ADS bibcode (and auto-completion wont be able to predict their
   bibcode IDs).
 
+  Set the -o/--open flag to open the PDF right after fetching.
+
 Examples
   # Fetch setting the BibTex key:
   bibm fetch BurbidgeEtal1957rvmpStellarElementSynthesis
@@ -977,7 +1024,7 @@ Examples
         help='Either a BibTex key or an ADS bibcode identifier.')
     fetch.add_argument('filename', action='store', nargs='?',
         help='Name for fetched PDF file.')
-    fetch.add_argument('-open', action='store_true', default=False,
+    fetch.add_argument('-o', '--open', action='store_true', default=False,
         help="Open the fetched PDF if the request succeeded.")
     fetch.set_defaults(func=cli_fetch)
 
